summaryrefslogtreecommitdiff
path: root/include/xmloff/styleexp.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'include/xmloff/styleexp.hxx')
-rw-r--r--include/xmloff/styleexp.hxx16
1 files changed, 8 insertions, 8 deletions
diff --git a/include/xmloff/styleexp.hxx b/include/xmloff/styleexp.hxx
index c58fc7f2d2c3..273248565006 100644
--- a/include/xmloff/styleexp.hxx
+++ b/include/xmloff/styleexp.hxx
@@ -24,7 +24,7 @@
#include <rtl/ustring.hxx>
#include <com/sun/star/uno/Reference.h>
-#include <xmloff/uniref.hxx>
+#include <salhelper/simplereferenceobject.hxx>
namespace com { namespace sun { namespace star
{
@@ -48,7 +48,7 @@ class SvXMLExportPropertyMapper;
class SvXMLAutoStylePoolP;
class SvXMLExport;
-class XMLOFF_DLLPUBLIC XMLStyleExport : public UniRefBase
+class XMLOFF_DLLPUBLIC XMLStyleExport : public salhelper::SimpleReferenceObject
{
SvXMLExport& rExport;
protected:
@@ -73,7 +73,7 @@ protected:
const ::com::sun::star::uno::Reference<
::com::sun::star::style::XStyle > & rStyle,
const OUString& rXMLFamily,
- const UniReference < SvXMLExportPropertyMapper >& rPropMapper,
+ const rtl::Reference < SvXMLExportPropertyMapper >& rPropMapper,
const ::com::sun::star::uno::Reference< ::com::sun::star::container::XNameAccess > & xStyles,
const OUString* pPrefix = 0L );
@@ -93,13 +93,13 @@ public:
// void exportStyleFamily(
// const OUString& rFamily, const OUString& rXMLFamily,
// const UniReference < XMLPropertySetMapper >& rPropMapper,
// bool bUsed, sal_uInt16 nFamily = 0,
// const OUString* pPrefix = 0L);
// void exportStyleFamily(
// const sal_Char *pFamily, const OUString& rXMLFamily,
// const UniReference < XMLPropertySetMapper >& rPropMapper,
// bool bUsed, sal_uInt16 nFamily = 0,
// const OUString* pPrefix = 0L);
@@ -107,17 +107,17 @@ public:
const ::com::sun::star::uno::Reference<
::com::sun::star::beans::XPropertySet > & xPropSet,
const OUString& rXMLFamily,
- const UniReference < SvXMLExportPropertyMapper >& rPropMapper );
+ const rtl::Reference < SvXMLExportPropertyMapper >& rPropMapper );
void exportStyleFamily(
const OUString& rFamily, const OUString& rXMLFamily,
- const UniReference < SvXMLExportPropertyMapper >& rPropMapper,
+ const rtl::Reference < SvXMLExportPropertyMapper >& rPropMapper,
bool bUsed, sal_uInt16 nFamily = 0,
const OUString* pPrefix = 0L);
void exportStyleFamily(
const sal_Char *pFamily, const OUString& rXMLFamily,
- const UniReference < SvXMLExportPropertyMapper >& rPropMapper,
+ const rtl::Reference < SvXMLExportPropertyMapper >& rPropMapper,
bool bUsed, sal_uInt16 nFamily = 0,
const OUString* pPrefix = 0L);
};
@@ -93,13 +93,13 @@ public:
// void exportStyleFamily(
// const OUString& rFamily, const OUString& rXMLFamily,
-// const UniReference < XMLPropertySetMapper >& rPropMapper,
+// const rtl::Reference < XMLPropertySetMapper >& rPropMapper,
// bool bUsed, sal_uInt16 nFamily = 0,
// const OUString* pPrefix = 0L);
@@ -93,13 +93,13 @@ public:
// void exportStyleFamily(
// const sal_Char *pFamily, const OUString& rXMLFamily,
-// const UniReference < XMLPropertySetMapper >& rPropMapper,
+// const rtl::Reference < XMLPropertySetMapper >& rPropMapper,
// bool bUsed, sal_uInt16 nFamily = 0,
// const OUString* pPrefix = 0L);